.. DataRobot Python Package documentation master file, created by
   sphinx-quickstart on Mon Mar 16 10:50:19 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Specialized workflows
======================

The following sections describe alternative workflows for a variety of specialized data types.

.. toctree::
   :maxdepth: 2

   datetime_partition.rst
   time_series.rst
   visualai.rst
   unsupervised_anomaly.rst
   unsupervised_clustering.rst
   segmented_modeling.rst
   custom_task.rst
   monotonic_constraints.rst
   binary_data.rst
